@@ -434,7 +434,7 @@ class Node
             $query .= "SELECT DB_first_level ";
             $query .= "FROM ( ";
             $query .= "SELECT DISTINCT SUBSTRING_INDEX(SCHEMA_NAME, ";
-            $query .= "'" . Util::sqlAddSlashes($dbSeparator) . "', 1) ";
+            $query .= "'" . $GLOBALS['dbi']->escapeString($dbSeparator) . "', 1) ";
             $query .= "DB_first_level ";
             $query .= "FROM INFORMATION_SCHEMA.SCHEMATA ";
             $query .= $this->_getWhereClause('SCHEMA_NAME', $searchClause);
@@ -444,9 +444,9 @@ class Node
             $query .= ") t2 ";
             $query .= $this->_getWhereClause('SCHEMA_NAME', $searchClause);
             $query .= "AND 1 = LOCATE(CONCAT(DB_first_level, ";
-            $query .= "'" . Util::sqlAddSlashes($dbSeparator) . "'), ";
+            $query .= "'" . $GLOBALS['dbi']->escapeString($dbSeparator) . "'), ";
             $query .= "CONCAT(SCHEMA_NAME, ";
-            $query .= "'" . Util::sqlAddSlashes($dbSeparator) . "')) ";
+            $query .= "'" . $GLOBALS['dbi']->escapeString($dbSeparator) . "')) ";
             $query .= "ORDER BY SCHEMA_NAME ASC";
             $retval = $GLOBALS['dbi']->fetchResult($query);
 
@@ -480,7 +480,7 @@ class Node
             $subClauses = array();
             foreach ($prefixes as $prefix) {
                 $subClauses[] = " LOCATE('"
-                    . Util::sqlAddSlashes($prefix) . $dbSeparator
+                    . $GLOBALS['dbi']->escapeString($prefix) . $dbSeparator
                     . "', "
                     . "CONCAT(`Database`, '" . $dbSeparator . "')) = 1 ";
             }
@@ -685,7 +685,7 @@ class Node
     {
         if (!empty($searchClause)) {
             $databases = array(
-                "%" . Util::sqlAddSlashes($searchClause, true) . "%",
+                "%" . $GLOBALS['dbi']->escapeString($searchClause, true) . "%",
             );
         } elseif (!empty($GLOBALS['cfg']['Server']['only_db'])) {
             $databases = $GLOBALS['cfg']['Server']['only_db'];
@@ -712,7 +712,7 @@ class Node
         if (!empty($searchClause)) {
             $whereClause .= "AND " . Util::backquote($columnName)
                 . " LIKE '%";
-            $whereClause .= Util::sqlAddSlashes(
+            $whereClause .= $GLOBALS['dbi']->escapeString(
                 $searchClause,
                 true
             );
@@ -721,7 +721,9 @@ class Node
 
         if (!empty($GLOBALS['cfg']['Server']['hide_db'])) {
             $whereClause .= "AND " . Util::backquote($columnName)
-                . " NOT REGEXP '" . $GLOBALS['cfg']['Server']['hide_db'] . "' ";
+                . " NOT REGEXP '"
+                . $GLOBALS['dbi']->escapeString($GLOBALS['cfg']['Server']['hide_db'], true)
+                . "' ";
         }
 
         if (!empty($GLOBALS['cfg']['Server']['only_db'])) {
@@ -735,7 +737,7 @@ class Node
             foreach ($GLOBALS['cfg']['Server']['only_db'] as $each_only_db) {
                 $subClauses[] = " " . Util::backquote($columnName)
                     . " LIKE '"
-                    . $each_only_db . "' ";
+                    . $GLOBALS['dbi']->escapeString($each_only_db, true) . "' ";
             }
             $whereClause .= implode("OR", $subClauses) . ") ";
         }
@@ -815,7 +817,7 @@ class Node
                 );
             $sqlQuery = "SELECT `db_name`, COUNT(*) AS `count` FROM " . $navTable
                 . " WHERE `username`='"
-                . Util::sqlAddSlashes(
+                . $GLOBALS['dbi']->escapeString(
                     $GLOBALS['cfg']['Server']['user']
                 ) . "'"
                 . " GROUP BY `db_name`";
